pecos.qeclib.steane.syn\_extract.six\_check\_nonflagging
========================================================

.. automodule:: pecos.qeclib.steane.syn_extract.six_check_nonflagging











   .. rubric:: Classes

   .. autosummary::

      SixUnflaggedSyn
